==> power_widget-0.0.34.tar.gz: lib/widgets/stateful/PowerStatefulCardView.dart <==
import 'package:flutter/widgets.dart';
import 'package:power_widget/serializable/WidgetSerializableModel.dart';
import 'package:power_widget/widgets/PowerCardView.dart';
import 'package:power_widget/widgets/stateful/ModularizedStatefulWidget.dart';

abstract class PowerStatefulCardView extends ModularizedStatefulWidget with PowerCardView {
  PowerStatefulCardViewState state;
  GlobalKey globalKey = GlobalKey();

  @override
  State<StatefulWidget> createState() {
    return PowerStatefulCardViewState(getSize(), provideCardViewPainter(), provideChildrenStack(), this, this, globalKey);
  }

  @override
  WidgetSerializableModel getWidgetSerializableModel() {
    // TODO: implement getWidgetSerializableModel
    return null;
  }

  void notifyWidgetUpdate() {
    globalKey.currentState.setState(() => {});
  }
}

class PowerStatefulCardViewState extends State<PowerStatefulCardView> {
  CustomPainter customPainter;
  Stack childrenStack;
  Size size;
  PowerCardView powerCardView;
  ModularizedStatefulWidget modularizedStatefulWidget;
  GlobalKey globalKey = GlobalKey();

  PowerStatefulCardViewState(this.size, this.customPainter, this.childrenStack, this.modularizedStatefulWidget, this.powerCardView, this.globalKey);

  @override
  Widget build(BuildContext context) {
    // TODO: implement build
    return Center(
      child: CustomPaint(
        child: modularizedStatefulWidget.provideChildrenStack(),
        size: powerCardView.getSize(),
        painter: powerCardView.provideCardViewPainter(),
      ),
    );
  }
}

==> power_widget-0.0.39.tar.gz: lib/widgets/stateful/PowerStatefulCardView.dart <==
import 'package:flutter/widgets.dart';
import 'package:power_widget/serializable/WidgetSerializableModel.dart';
import 'package:power_widget/widgets/PowerCardView.dart';
import 'package:power_widget/widgets/stateful/ModularizedStatefulWidget.dart';

abstract class PowerStatefulCardView extends ModularizedStatefulWidget with PowerCardView {
  PowerStatefulCardViewState state;
  GlobalKey globalKey = GlobalKey();

  @override
  State<StatefulWidget> createState() {
    return PowerStatefulCardViewState(getSize(), provideCardViewPainter(), provideChildrenStack(), this, this, globalKey);
  }

  @override
  WidgetSerializableModel getWidgetSerializableModel() {
    // TODO: implement getWidgetSerializableModel
    return null;
  }

  void notifyWidgetUpdate() {
    globalKey.currentState.setState(() => {});
  }
}

class PowerStatefulCardViewState extends State<PowerStatefulCardView> {
  CustomPainter customPainter;
  Stack childrenStack;
  Size size;
  PowerCardView powerCardView;
  ModularizedStatefulWidget modularizedStatefulWidget;
  GlobalKey globalKey = GlobalKey();

  PowerStatefulCardViewState(this.size, this.customPainter, this.childrenStack, this.modularizedStatefulWidget, this.powerCardView, this.globalKey);

  @override
  Widget build(BuildContext context) {
    CustomPaint customPaint;
    if (modularizedStatefulWidget
        .provideWidgets()
        .isNotEmpty) {
      customPaint = CustomPaint(child: modularizedStatefulWidget.provideWidgets()[0],
          size: powerCardView.getSize(),
          painter: powerCardView.provideCardViewPainter());
    } else {
      customPaint = CustomPaint(size: powerCardView.getSize(), painter: powerCardView.provideCardViewPainter());
    }
    return Center(
      child: customPaint,
    );
  }
}
